# Installation

```
pip3 install --upgrade ezcode
```

# PyPi Releases

https://pypi.org/project/ezcode/#history


# Development Workflow
```
git clone https://github.com/zheng-gao/ez_code.git && cd ez_code
./ez.sh --development
```

# Release Workflow

```
git clone https://github.com/zheng-gao/ez_code.git && cd ez_code
./ez.sh --release
```

# Contents
* [Array](src/ezcode/array/array.md)
* [List](src/ezcode/list/list.md)
* [Tree](src/ezcode/tree/tree.md)
* [Graph](src/ezcode/graph/graph.md)
* [Math](src/ezcode/math/math.md)


